==> 4.2.0.tar.gz: lib/src/presentation/widgets/dialogs.dart <==
import 'package:dcoupon_sdk_flutter_package/src/presentation/widgets/html_dialog_widget.dart';
import 'package:flutter/material.dart';

class MyDialogs {
  static showHtmlDialog(
    BuildContext context, {
    required String data,
    String? title,
  }) {
    showDialog(
      barrierColor: Colors.black38,
      context: context,
      barrierDismissible: false, // user must tap title or dialog!
      builder: (BuildContext context) {
        return Dialog(
          elevation: 0,
          insetPadding: EdgeInsets.symmetric(
            horizontal: 24,
            vertical: 24,
          ),
          shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(6.0),
          ),
          backgroundColor: Colors.transparent,
          child: Stack(
            children: [
              HtmlDialogWidget(data: data),
              title != null
                  ? Positioned(
                      top: 0.0,
                      right: 0.0,
                      child: Card(
                        child: Padding(
                          padding: const EdgeInsets.all(8.0),
                          child: Text(title),
                        ),
                      ),
                    )
                  : Container(),
              Positioned(
                top: 36.0,
                left: 0.0,
                child: GestureDetector(
                  onTap: () {
                    Navigator.of(context).pop();
                  },
                  child: Align(
                    alignment: Alignment.topRight,
                    child: CircleAvatar(
                      radius: 14.0,
                      backgroundColor: Theme.of(context).colorScheme.background,
                      child: Icon(
                        Icons.close,
                        color: Theme.of(context).textTheme.bodyText2!.color,
                      ),
                    ),
                  ),
                ),
              ),
            ],
          ),
        );
      },
    );
  }
}

==> 4.4.2.tar.gz: lib/src/presentation/widgets/dialogs.dart <==
import 'package:dcoupon_sdk_flutter_package/src/presentation/widgets/webview_dialog_widget.dart';
import 'package:flutter/material.dart';

class MyDialogs {
  static showWebviewDialog(
    BuildContext context, {
    required String? url,
    String? title,
  }) {
    showDialog(
      barrierColor: Colors.black38,
      context: context,
      barrierDismissible: false, // user must tap title or dialog!
      builder: (BuildContext context) {
        return Dialog(
          elevation: 0,
          insetPadding: EdgeInsets.symmetric(
            horizontal: 24,
            vertical: 24,
          ),
          shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(10.0),
          ),
          backgroundColor: Colors.transparent,
          child: Stack(
            children: [
              WebviewDialogWidget(url: url),
              title != null
                  ? Positioned(
                      top: 0.0,
                      right: 0.0,
                      child: Card(
                        child: Padding(
                          padding: const EdgeInsets.all(8.0),
                          child: Text(title),
                        ),
                      ),
                    )
                  : Container(),
              Positioned(
                top: 36.0,
                left: 0.0,
                child: GestureDetector(
                  onTap: () {
                    Navigator.of(context).pop();
                  },
                  child: Align(
                    alignment: Alignment.topRight,
                    child: CircleAvatar(
                      radius: 14.0,
                      backgroundColor: Theme.of(context).colorScheme.background,
                      child: Icon(
                        Icons.close,
                        color: Theme.of(context).textTheme.bodyText2!.color,
                      ),
                    ),
                  ),
                ),
              ),
            ],
          ),
        );
      },
    );
  }
}
